@@ -156,9 +156,12 @@ message RelatedFieldModelResponse {
     string uuid = 1;
     ForeignModelResponse foreign_obj = 2;
     repeated ManyManyModelResponse many_many_obj = 3;
-    string custom_field_name = 4;
-    string foreign = 5;
-    repeated string many_many = 6;
+    int32 slug_test_model = 4;
+    repeated bool slug_reverse_test_model = 5;
+    repeated string slug_many_many = 6;
+    string custom_field_name = 7;
+    string foreign = 8;
+    repeated string many_many = 9;
 }
 
 message ForeignModelResponse {
@@ -181,9 +184,16 @@ message RelatedFieldModelListResponse {
 
 message RelatedFieldModelRequest {
     string uuid = 1;
-    string custom_field_name = 2;
-    string foreign = 3;
-    repeated string many_many = 4;
+    repeated ManyManyModelRequest many_many_obj = 2;
+    string custom_field_name = 3;
+    string foreign = 4;
+    repeated string many_many = 5;
+}
+
+message ManyManyModelRequest {
+    string uuid = 1;
+    string name = 2;
+    string test_write_only_on_nested = 3;
 }
 
 message RelatedFieldModelRetrieveRequest {
@@ -343,6 +353,7 @@ message SpecialFieldsModelResponse {
     string uuid = 1;
     google.protobuf.Struct meta_datas = 2;
     repeated int32 list_datas = 3;
+    bytes binary = 4;
 }
 
 message SpecialFieldsModelListRequest {
@@ -375,6 +386,8 @@ import "google/protobuf/struct.proto";
 service BasicController {
     rpc FetchDataForUser(BasicFetchDataForUserRequest) returns (BasicServiceResponse) {}
     rpc TestEmptyMethod(google.protobuf.Empty) returns (google.protobuf.Empty) {}
+    rpc GetMultiple(google.protobuf.Empty) returns (BasicGetMultipleListResponse) {}
+    rpc MyMethod(CustomNameForRequest) returns (CustomNameForResponse) {}
 }
 
 message BasicFetchDataForUserRequest {
@@ -384,6 +397,20 @@ message BasicFetchDataForUserRequest {
 message BasicServiceResponse {
     string user_name = 1;
     google.protobuf.Struct user_data = 2;
+    bytes bytes_example = 3;
+}
+
+message BasicGetMultipleListResponse {
+    repeated BasicServiceResponse results = 1;
+    int32 count = 2;
+}
+
+message CustomNameForRequest {
+    string user_name = 1;
+}
+
+message CustomNameForResponse {
+    string user_name = 1;
 }
 
 """
@@ -427,6 +454,8 @@ service SpecialFieldsModelController {
 service BasicController {
     rpc FetchDataForUser(BasicFetchDataForUserRequest) returns (BasicService) {}
     rpc TestEmptyMethod(google.protobuf.Empty) returns (google.protobuf.Empty) {}
+    rpc GetMultiple(google.protobuf.Empty) returns (BasicGetMultipleListResponse) {}
+    rpc MyMethod(CustomNameForRequest) returns (CustomNameForResponse) {}
 }
 
 service ForeignModelController {
@@ -434,6 +463,10 @@ service ForeignModelController {
     rpc Retrieve(ForeignModelRetrieveCustomRetrieveRequest) returns (ForeignModelRetrieveCustom) {}
 }
 
+service ImportStructEvenInArrayModelController {
+    rpc Create(ImportStructEvenInArrayModel) returns (ImportStructEvenInArrayModel) {}
+}
+
 service RelatedFieldModelController {
     rpc List(RelatedFieldModelListRequest) returns (RelatedFieldModelListResponse) {}
     rpc Create(RelatedFieldModel) returns (RelatedFieldModel) {}
@@ -442,10 +475,6 @@ service RelatedFieldModelController {
     rpc Destroy(RelatedFieldModelDestroyRequest) returns (google.protobuf.Empty) {}
 }
 
-service ImportStructEvenInArrayModelController {
-    rpc Create(ImportStructEvenInArrayModel) returns (ImportStructEvenInArrayModel) {}
-}
-
 message UnitTestModelListWithExtraArgsRequest {
     bool archived = 1;
 }
@@ -484,25 +513,20 @@ message BasicService {
     string user_name = 1;
     google.protobuf.Struct user_data = 2;
     string user_password = 3;
+    bytes bytes_example = 4;
 }
 
-message UnitTestModelListRequest {
-}
-
-message UnitTestModelListResponse {
-    repeated UnitTestModel results = 1;
+message BasicGetMultipleListResponse {
+    repeated BasicService results = 1;
     int32 count = 2;
 }
 
-message UnitTestModelRetrieveRequest {
-    int32 id = 1;
+message CustomNameForRequest {
+    string user_name = 1;
 }
 
-message UnitTestModelDestroyRequest {
-    int32 id = 1;
-}
-
-message UnitTestModelStreamRequest {
+message CustomNameForResponse {
+    string user_name = 1;
 }
 
 message ForeignModel {
@@ -527,18 +551,27 @@ message ForeignModelRetrieveCustom {
     string custom = 2;
 }
 
+message ImportStructEvenInArrayModel {
+    string uuid = 1;
+    repeated google.protobuf.Struct this_is_crazy = 2;
+}
+
 message RelatedFieldModel {
     string uuid = 1;
     ForeignModel foreign_obj = 2;
     repeated ManyManyModel many_many_obj = 3;
-    string custom_field_name = 4;
-    string foreign = 5;
-    repeated string many_many = 6;
+    int32 slug_test_model = 4;
+    repeated bool slug_reverse_test_model = 5;
+    repeated string slug_many_many = 6;
+    string custom_field_name = 7;
+    string foreign = 8;
+    repeated string many_many = 9;
 }
 
 message ManyManyModel {
     string uuid = 1;
     string name = 2;
+    string test_write_only_on_nested = 3;
 }
 
 message RelatedFieldModelListRequest {
@@ -561,6 +594,7 @@ message SpecialFieldsModel {
     string uuid = 1;
     google.protobuf.Struct meta_datas = 2;
     repeated int32 list_datas = 3;
+    bytes binary = 4;
 }
 
 message SpecialFieldsModelListRequest {
@@ -575,9 +609,23 @@ message SpecialFieldsModelDestroyRequest {
     string uuid = 1;
 }
 
-message ImportStructEvenInArrayModel {
-    string uuid = 1;
-    repeated google.protobuf.Struct this_is_crazy = 2;
+message UnitTestModelListRequest {
+}
+
+message UnitTestModelListResponse {
+    repeated UnitTestModel results = 1;
+    int32 count = 2;
+}
+
+message UnitTestModelRetrieveRequest {
+    int32 id = 1;
+}
+
+message UnitTestModelDestroyRequest {
+    int32 id = 1;
+}
+
+message UnitTestModelStreamRequest {
 }
 
 """
@@ -620,6 +668,8 @@ service SpecialFieldsModelController {
 service BasicController {
     rpc FetchDataForUser(BasicFetchDataForUserRequest) returns (BasicServiceResponse) {}
     rpc TestEmptyMethod(google.protobuf.Empty) returns (google.protobuf.Empty) {}
+    rpc GetMultiple(google.protobuf.Empty) returns (BasicGetMultipleListResponse) {}
+    rpc MyMethod(CustomNameForRequest) returns (CustomNameForResponse) {}
 }
 
 service ForeignModelController {
@@ -627,6 +677,10 @@ service ForeignModelController {
     rpc Retrieve(ForeignModelRetrieveCustomRetrieveRequest) returns (ForeignModelRetrieveCustomResponse) {}
 }
 
+service ImportStructEvenInArrayModelController {
+    rpc Create(ImportStructEvenInArrayModelRequest) returns (ImportStructEvenInArrayModelResponse) {}
+}
+
 service RelatedFieldModelController {
     rpc List(RelatedFieldModelListRequest) returns (RelatedFieldModelListResponse) {}
     rpc Create(RelatedFieldModelRequest) returns (RelatedFieldModelResponse) {}
@@ -635,10 +689,6 @@ service RelatedFieldModelController {
     rpc Destroy(RelatedFieldModelDestroyRequest) returns (google.protobuf.Empty) {}
 }
 
-service ImportStructEvenInArrayModelController {
-    rpc Create(ImportStructEvenInArrayModelRequest) returns (ImportStructEvenInArrayModelResponse) {}
-}
-
 message UnitTestModelListWithExtraArgsRequest {
     bool archived = 1;
 }
@@ -676,6 +726,124 @@ message BasicFetchDataForUserRequest {
 message BasicServiceResponse {
     string user_name = 1;
     google.protobuf.Struct user_data = 2;
+    bytes bytes_example = 3;
+}
+
+message BasicGetMultipleListResponse {
+    repeated BasicServiceResponse results = 1;
+    int32 count = 2;
+}
+
+message CustomNameForRequest {
+    string user_name = 1;
+}
+
+message CustomNameForResponse {
+    string user_name = 1;
+}
+
+message ForeignModelResponse {
+    string uuid = 1;
+    string name = 2;
+}
+
+message ForeignModelListRequest {
+}
+
+message ForeignModelListResponse {
+    repeated ForeignModelResponse results = 1;
+    int32 count = 2;
+}
+
+message ForeignModelRetrieveCustomRetrieveRequest {
+    string name = 1;
+}
+
+message ForeignModelRetrieveCustomResponse {
+    string name = 1;
+    string custom = 2;
+}
+
+message ImportStructEvenInArrayModelRequest {
+    string uuid = 1;
+    repeated google.protobuf.Struct this_is_crazy = 2;
+}
+
+message ImportStructEvenInArrayModelResponse {
+    string uuid = 1;
+    repeated google.protobuf.Struct this_is_crazy = 2;
+}
+
+message RelatedFieldModelResponse {
+    string uuid = 1;
+    ForeignModelResponse foreign_obj = 2;
+    repeated ManyManyModelResponse many_many_obj = 3;
+    int32 slug_test_model = 4;
+    repeated bool slug_reverse_test_model = 5;
+    repeated string slug_many_many = 6;
+    string custom_field_name = 7;
+    string foreign = 8;
+    repeated string many_many = 9;
+}
+
+message ManyManyModelResponse {
+    string uuid = 1;
+    string name = 2;
+}
+
+message RelatedFieldModelListRequest {
+}
+
+message RelatedFieldModelListResponse {
+    repeated RelatedFieldModelResponse list_custom_field_name = 1;
+    int32 count = 2;
+}
+
+message RelatedFieldModelRequest {
+    string uuid = 1;
+    repeated ManyManyModelRequest many_many_obj = 2;
+    string custom_field_name = 3;
+    string foreign = 4;
+    repeated string many_many = 5;
+}
+
+message ManyManyModelRequest {
+    string uuid = 1;
+    string name = 2;
+    string test_write_only_on_nested = 3;
+}
+
+message RelatedFieldModelRetrieveRequest {
+    string uuid = 1;
+}
+
+message RelatedFieldModelDestroyRequest {
+    string uuid = 1;
+}
+
+message SpecialFieldsModelResponse {
+    string uuid = 1;
+    google.protobuf.Struct meta_datas = 2;
+    repeated int32 list_datas = 3;
+    bytes binary = 4;
+}
+
+message SpecialFieldsModelListRequest {
+}
+
+message SpecialFieldsModelListResponse {
+    repeated SpecialFieldsModelResponse results = 1;
+    int32 count = 2;
+}
+
+message SpecialFieldsModelRequest {
+    string uuid = 1;
+    google.protobuf.Struct meta_datas = 2;
+    repeated int32 list_datas = 3;
+}
+
+message SpecialFieldsModelDestroyRequest {
+    string uuid = 1;
 }
 
 message UnitTestModelListRequest {
@@ -703,97 +871,4 @@ message UnitTestModelDestroyRequest {
 message UnitTestModelStreamRequest {
 }
 
-message ForeignModelResponse {
-    string uuid = 1;
-    string name = 2;
-}
-
-message ForeignModelListRequest {
-}
-
-message ForeignModelListResponse {
-    repeated ForeignModelResponse results = 1;
-    int32 count = 2;
-}
-
-message ForeignModelRetrieveCustomRetrieveRequest {
-    string name = 1;
-}
-
-message ForeignModelRetrieveCustomResponse {
-    string name = 1;
-    string custom = 2;
-}
-
-message RelatedFieldModelResponse {
-    string uuid = 1;
-    ForeignModelResponse foreign_obj = 2;
-    repeated ManyManyModelResponse many_many_obj = 3;
-    string custom_field_name = 4;
-    string foreign = 5;
-    repeated string many_many = 6;
-}
-
-message ManyManyModelResponse {
-    string uuid = 1;
-    string name = 2;
-}
-
-message RelatedFieldModelListRequest {
-}
-
-message RelatedFieldModelListResponse {
-    repeated RelatedFieldModelResponse list_custom_field_name = 1;
-    int32 count = 2;
-}
-
-message RelatedFieldModelRequest {
-    string uuid = 1;
-    string custom_field_name = 2;
-    string foreign = 3;
-    repeated string many_many = 4;
-}
-
-message RelatedFieldModelRetrieveRequest {
-    string uuid = 1;
-}
-
-message RelatedFieldModelDestroyRequest {
-    string uuid = 1;
-}
-
-message SpecialFieldsModelResponse {
-    string uuid = 1;
-    google.protobuf.Struct meta_datas = 2;
-    repeated int32 list_datas = 3;
-}
-
-message SpecialFieldsModelListRequest {
-}
-
-message SpecialFieldsModelListResponse {
-    repeated SpecialFieldsModelResponse results = 1;
-    int32 count = 2;
-}
-
-message SpecialFieldsModelRequest {
-    string uuid = 1;
-    google.protobuf.Struct meta_datas = 2;
-    repeated int32 list_datas = 3;
-}
-
-message SpecialFieldsModelDestroyRequest {
-    string uuid = 1;
-}
-
-message ImportStructEvenInArrayModelRequest {
-    string uuid = 1;
-    repeated google.protobuf.Struct this_is_crazy = 2;
-}
-
-message ImportStructEvenInArrayModelResponse {
-    string uuid = 1;
-    repeated google.protobuf.Struct this_is_crazy = 2;
-}
-
 """
