@@ -1,3 +1,4 @@
+import inspect
 from collections import OrderedDict
 from typing import Dict, List, Tuple
 
@@ -6,6 +7,7 @@ from rest_framework.fields import (
     DictField,
     HiddenField,
     ListField,
+    ModelField,
     ReadOnlyField,
     SerializerMethodField,
 )
@@ -16,6 +18,13 @@ from rest_framework.utils.model_meta import get_field_info
 from django_socio_grpc.proto_serializers import BaseProtoSerializer, ListProtoSerializer
 from django_socio_grpc.settings import grpc_settings
 from django_socio_grpc.utils import model_meta
+from django_socio_grpc.utils.tools import rreplace
+
+DEFAULT_LIST_FIELD_NAME = "results"
+
+
+class RegisterServiceException(Exception):
+    pass
 
 
 class SingletonMeta(type):
@@ -71,8 +80,6 @@ class RegistrySingleton(metaclass=SingletonMeta):
     """
 
     type_mapping = {
-        # Special
-        models.JSONField.__name__: "google.protobuf.Struct",
         # Numeric
         models.AutoField.__name__: "int32",
         models.SmallIntegerField.__name__: "int32",
@@ -99,10 +106,26 @@ class RegistrySingleton(metaclass=SingletonMeta):
         models.UUIDField.__name__: "string",
         models.GenericIPAddressField.__name__: "string",
         models.FilePathField.__name__: "string",
+        # Other
+        models.BinaryField.__name__: "bytes",
         # Default
         models.Field.__name__: "string",
     }
 
+    # JSONField and PositiveBigIntegerField not available on Django 2.2
+    try:
+        # Special
+        type_mapping[models.JSONField.__name__] = "google.protobuf.Struct"
+    except AttributeError:
+        from django.contrib.postgres.fields import JSONField
+
+        type_mapping[JSONField.__name__] = "google.protobuf.Struct"
+
+    try:
+        type_mapping[models.PositiveBigIntegerField.__name__] = "int64"
+    except AttributeError:
+        pass
+
     _instances = {}
 
     @classmethod
@@ -154,7 +177,13 @@ class RegistrySingleton(metaclass=SingletonMeta):
 
             field_grpc_generator_format = (
                 field_name,
-                self.get_proto_type(app_name, field_type, field_name, serializer_instance),
+                self.get_proto_type(
+                    app_name,
+                    field_type,
+                    field_name,
+                    serializer_instance,
+                    is_request=is_request,
+                ),
             )
 
             self.registered_app[app_name]["registered_messages"][message_name].append(
@@ -177,12 +206,17 @@ class RegistrySingleton(metaclass=SingletonMeta):
     ):
         # INFO - AM - 21/01/2022 - if SEPARATE_READ_WRITE_MODEL is true (by default yes) then we have two different message for the same serializer
         class_name = class_or_field_instance.__class__.__name__
-        message_name = class_name.replace("ProtoSerializer", "").replace("Serializer", "")
+        if "ProtoSerializer" in class_name:
+            message_name = rreplace(class_name, "ProtoSerializer", "", 1)
+        elif "Serializer" in class_name:
+            message_name = rreplace(class_name, "Serializer", "", 1)
         if grpc_settings.SEPARATE_READ_WRITE_MODEL and append_type:
             message_name = f"{message_name}{'Request' if is_request else 'Response'}"
         return message_name
 
-    def get_proto_type(self, app_name, field_type, field_name, serializer_instance):
+    def get_proto_type(
+        self, app_name, field_type, field_name, serializer_instance, is_request=None
+    ):
         """
         Return a proto_type  to use in the proto file from a field type.
         For SerializerMethodField we also need field_name and serializer_instance
@@ -194,7 +228,7 @@ class RegistrySingleton(metaclass=SingletonMeta):
 
         proto_type = self.type_mapping.get(field_type.__class__.__name__, "string")
 
-        # if  field_name == "default_method_field":
+        # if  field_name == "slug_many_many":
         #     print(f"class is : {field_type.__class__}")
         #     print(f"is subclas of ListProtoSerializer: {issubclass(field_type.__class__, ListProtoSerializer)}")
         #     print(f"is subclas of BaseProtoSerializer: {issubclass(field_type.__class__, BaseProtoSerializer)}")
@@ -211,20 +245,20 @@ class RegistrySingleton(metaclass=SingletonMeta):
 
         # INFO - AM - 07/01/2022 - If the field type inherit of ListProtoSerializer that mean we have
         if issubclass(field_type.__class__, ListProtoSerializer):
-            proto_type = f"repeated {self.get_message_name_from_field_or_serializer_instance(field_type.child, is_request=False)}"
+            proto_type = f"repeated {self.get_message_name_from_field_or_serializer_instance(field_type.child, is_request=is_request)}"
             # INFO - AM - 07/01/2022 - If nested serializer not used anywhere else we need to add it too
             self.register_serializer_as_message_if_not_exist(
-                app_name, field_type.child, is_request=False
+                app_name, field_type.child, is_request=is_request
             )
 
         # INFO - AM - 07/01/2022 - else if the field type inherit from proto serializer that mean that it is generated as a message in the proto file
         elif issubclass(field_type.__class__, BaseProtoSerializer):
             proto_type = self.get_message_name_from_field_or_serializer_instance(
-                field_type, is_request=False
+                field_type, is_request=is_request
             )
             # INFO - AM - 07/01/2022 - If nested serializer not used anywhere else we need to add it too
             self.register_serializer_as_message_if_not_exist(
-                app_name, field_type, is_request=False
+                app_name, field_type, is_request=is_request
             )
 
         # INFO - AM - 07/01/2022 - Else if the field type inherit from the SlugRelatedField that mean the type is the type name attribute in the foreign model
@@ -235,9 +269,17 @@ class RegistrySingleton(metaclass=SingletonMeta):
 
         # INFO - AM - 07/01/2022 - Else if the field type inherit from the ManyRelatedField that mean the type is the type of the pk of the child_relation (see relations.py of drf)
         elif issubclass(field_type.__class__, ManyRelatedField):
-            proto_type = (
-                f"repeated {self.get_pk_from_related_field(field_type.child_relation)}"
+            child_proto_type = self.get_proto_type(
+                app_name,
+                field_type.child_relation,
+                field_name,
+                serializer_instance,
+                is_request=is_request,
             )
+            # INFO - AM - 03/02/2022 - if the returned child_proto_type returned is repeated (this can happen with slud related field in a many many relationships) we remove it because we only need one repeated
+            if child_proto_type.startswith("repeated "):
+                child_proto_type = child_proto_type[9:]
+            proto_type = f"repeated {child_proto_type}"
 
         # INFO - AM - 07/01/2022 - Else if the field type inherit from the RelatedField that mean the type is the type of the pk of the foreign model
         elif issubclass(field_type.__class__, RelatedField):
@@ -247,6 +289,12 @@ class RegistrySingleton(metaclass=SingletonMeta):
         elif issubclass(field_type.__class__, ListSerializer):
             proto_type = "repeated google.protobuf.Struct"
 
+        # INFO - AM - 07/01/2022 - Else if the field type inherit from the ListField that mean it's a repaeated of the child attr proto type
+        elif issubclass(field_type.__class__, ModelField):
+            proto_type = self.type_mapping.get(
+                field_type.model_field.__class__.__name__, "string"
+            )
+
         # INFO - AM - 07/01/2022 - Else if the field type inherit from the ListField that mean it's a repaeated of the child attr proto type
         elif issubclass(field_type.__class__, ListField):
             child_type = self.type_mapping.get(field_type.child.__class__.__name__, "string")
@@ -281,7 +329,7 @@ class RegistrySingleton(metaclass=SingletonMeta):
             return "string"
 
         if "return" not in method.__annotations__:
-            raise Exception(
+            raise RegisterServiceException(
                 f"You are trying to register the serializer {serializer_instance.__class__.__name__} with a SerializerMethodField on the field {field_name}. But the method associated does'nt have a return annotations. Please look at the example: https://github.com/socotecio/django-socio-grpc/blob/master/django_socio_grpc/tests/fakeapp/serializers.py#L83. And the python doc: https://docs.python.org/3.8/library/typing.html"
             )
 
@@ -289,9 +337,10 @@ class RegistrySingleton(metaclass=SingletonMeta):
             int: "int32",
             str: "string",
             bool: "bool",
+            float: "float",
             list: "repeated string",
-            float: "repeated float",
             dict: "google.protobuf.Struct",
+            bytes: "bytes",
             List: "repeated string",
             Dict: "google.protobuf.Struct",
             List[int]: "repeated int32",
@@ -376,6 +425,50 @@ class RegistrySingleton(metaclass=SingletonMeta):
 
         return proto_type
 
+    def register_list_response_message_of_serializer(
+        self,
+        app_name,
+        service_instance,
+        base_name,
+        list_response_field_name,
+        child_response_message_name,
+        message_name=None,
+    ):
+
+        pagination = service_instance.pagination_class
+        if pagination is None:
+            pagination = grpc_settings.DEFAULT_PAGINATION_CLASS is not None
+
+        response_fields = [
+            (list_response_field_name, f"repeated {child_response_message_name}")
+        ]
+        if pagination:
+            response_fields += [("count", "int32")]
+
+        if message_name:
+            response_message_name = message_name
+        else:
+            response_message_name = f"{base_name}ListResponse"
+
+        self.registered_app[app_name]["registered_messages"][
+            response_message_name
+        ] = response_fields
+
+        return response_message_name
+
+    def get_list_response_field_name_from_serializer_instance(self, serializer_instance):
+
+        list_response_field_name = DEFAULT_LIST_FIELD_NAME
+
+        # INFO - AM - 14/01/2022 - We let the possibility to the user to customize the name of the attr where the list items are set by message_list_attr attr in meta class. If not present we use the default results
+        serializer_meta = getattr(serializer_instance, "Meta", None)
+        if serializer_meta:
+            message_list_attr = getattr(serializer_meta, "message_list_attr", None)
+            if message_list_attr:
+                list_response_field_name = message_list_attr
+
+        return list_response_field_name
+
     ############################################################################
     #
     # Default Registration (from know method with no decorator)
@@ -460,7 +553,7 @@ class RegistrySingleton(metaclass=SingletonMeta):
             }
 
         else:
-            raise Exception(
+            raise RegisterServiceException(
                 f"You are registering a service with the method {method} but this methods does not have a decorator and is not in our default supported methods: {KnowMethods.get_as_list()}"
             )
 
@@ -505,7 +598,7 @@ class RegistrySingleton(metaclass=SingletonMeta):
             return self.register_stream_serializer_as_message(app_name, serializer_instance)
 
         else:
-            raise Exception(
+            raise RegisterServiceException(
                 f"You are registering a service with the method {method} but this methods does not have a decorator and is not in our default supported methods: {KnowMethods.get_as_list()}"
             )
 
@@ -532,35 +625,24 @@ class RegistrySingleton(metaclass=SingletonMeta):
         serializer_name = self.get_message_name_from_field_or_serializer_instance(
             serializer_instance, append_type=False
         )
-
         child_response_message_name = self.register_serializer_as_message_if_not_exist(
             app_name, serializer_instance, is_request=False
         )
 
-        pagination = service_instance.pagination_class
-        if pagination is None:
-            pagination = grpc_settings.DEFAULT_PAGINATION_CLASS is not None
-
-        response_field_name = "results"
-
-        # INFO - AM - 14/01/2022 - We let the possibility to the user to customize the name of the attr where the list items are set by message_list_attr attr in meta class. If not present we use the default results
-        serializer_meta = getattr(serializer_instance, "Meta", None)
-        if serializer_meta:
-            message_list_attr = getattr(serializer_meta, "message_list_attr", None)
-            if message_list_attr:
-                response_field_name = message_list_attr
-
-        response_fields = [(response_field_name, f"repeated {child_response_message_name}")]
-        if pagination:
-            response_fields += [("count", "int32")]
+        list_response_field_name = self.get_list_response_field_name_from_serializer_instance(
+            serializer_instance
+        )
 
         request_message_name = f"{serializer_name}ListRequest"
-        response_message_name = f"{serializer_name}ListResponse"
-
         self.registered_app[app_name]["registered_messages"][request_message_name] = []
-        self.registered_app[app_name]["registered_messages"][
-            response_message_name
-        ] = response_fields
+
+        response_message_name = self.register_list_response_message_of_serializer(
+            app_name,
+            service_instance,
+            base_name=serializer_name,
+            list_response_field_name=list_response_field_name,
+            child_response_message_name=child_response_message_name,
+        )
 
         return request_message_name, response_message_name
 
@@ -644,7 +726,7 @@ class RegistrySingleton(metaclass=SingletonMeta):
 
         # TODO - AM - 07/01/2022 - Check if the fied name in the existing field
         if field_name not in serializer_instance.fields:
-            raise Exception(
+            raise RegisterServiceException(
                 f"Trying to build a Retrieve or Destroy request with retrieve field named: {field_name} but this field is not existing in the serializer: {serializer_instance.__class__.__name__}"
             )
 
@@ -667,10 +749,13 @@ class RegistrySingleton(metaclass=SingletonMeta):
         function_name,
         request=None,
         response=None,
+        request_name=None,
+        response_name=None,
         request_stream=False,
         response_stream=False,
+        use_request_list=False,
+        use_response_list=False,
     ):
-
         app_name = self.get_app_name_from_service_class(service_class)
         # INFO - AM - 14/01/2022 - Initialize the app in the project to be generated as a specific proto file
         if app_name not in self.registered_app:
@@ -681,12 +766,59 @@ class RegistrySingleton(metaclass=SingletonMeta):
 
         service_instance = service_class()
         service_name = service_instance.get_service_name()
-        request_message_name = self.register_message_for_custom_action(
-            app_name, service_name, function_name, request, is_request=True
+
+        (
+            request_message_name,
+            list_response_field_name,
+        ) = self.register_message_for_custom_action(
+            app_name,
+            service_name,
+            function_name,
+            request,
+            is_request=True,
+            message_name=request_name,
         )
-        response_message_name = self.register_message_for_custom_action(
-            app_name, service_name, function_name, response, is_request=False
+        if use_request_list:
+            if response_name:
+                base_name = rreplace(response_name, "Request", "", 1)
+            else:
+                base_name = f"{service_name}{function_name}"
+            request_message_name = self.register_list_response_message_of_serializer(
+                app_name,
+                service_instance,
+                base_name=base_name,
+                list_response_field_name=list_response_field_name,
+                child_response_message_name=request_message_name,
+                message_name=request_name,
+            )
+
+        (
+            response_message_name,
+            list_response_field_name,
+        ) = self.register_message_for_custom_action(
+            app_name,
+            service_name,
+            function_name,
+            response,
+            is_request=False,
+            message_name=response_name,
         )
+        if use_response_list:
+            if response_name:
+                base_name = rreplace(response_name, "Response", "", 1)
+            else:
+                base_name = f"{service_name}{function_name}"
+            response_message_name = self.register_list_response_message_of_serializer(
+                app_name,
+                service_instance,
+                base_name=base_name,
+                list_response_field_name=list_response_field_name,
+                child_response_message_name=response_message_name,
+            )
+        # INFO - AM - 03/02/3022 - If user specified a response name we use it instead of the automatically generated one
+        if response_name:
+            response_message_name = response_name
+
         self.register_method_for_custom_action(
             app_name,
             service_name,
@@ -720,33 +852,40 @@ class RegistrySingleton(metaclass=SingletonMeta):
         }
 
     def register_message_for_custom_action(
-        self, app_name, service_name, function_name, message, is_request
+        self, app_name, service_name, function_name, message, is_request, message_name=None
     ):
         if isinstance(message, list):
             if len(message) == 0:
-                return "google.protobuf.Empty"
+                return "google.protobuf.Empty", DEFAULT_LIST_FIELD_NAME
 
             messages_fields = [(item["name"], item["type"]) for item in message]
 
-            message_name = (
-                f"{service_name}{function_name}{'Request' if is_request else 'Response'}"
-            )
+            if message_name is None:
+                message_name = (
+                    f"{service_name}{function_name}{'Request' if is_request else 'Response'}"
+                )
             self.registered_app[app_name]["registered_messages"][
                 message_name
             ] = messages_fields
-            return message_name
+            return message_name, DEFAULT_LIST_FIELD_NAME
 
         elif isinstance(message, str):
             # TODO - AM - 27/01/2022 - Maybe check for authorized string like google.protobuf.empty to avoid developer making syntax mistake
-            return message
-        elif issubclass(message, BaseSerializer):
+            return message, DEFAULT_LIST_FIELD_NAME
+        elif inspect.isclass(message) and issubclass(message, BaseSerializer):
             serializer_instance = message()
-            return self.register_serializer_as_message_if_not_exist(
-                app_name, serializer_instance, is_request=is_request
+            list_response_field_name = (
+                self.get_list_response_field_name_from_serializer_instance(serializer_instance)
+            )
+            return (
+                self.register_serializer_as_message_if_not_exist(
+                    app_name, serializer_instance, is_request=is_request
+                ),
+                list_response_field_name,
             )
         else:
-            raise Exception(
-                f"{'Request' if is_request else 'Response'} message for function {function_name} in app {app_name} is not a list or a serializer"
+            raise RegisterServiceException(
+                f"{'Request' if is_request else 'Response'} message for function {function_name} in app {app_name} is not a list, a serializer or a string"
             )
 
     def get_app_name_from_service_class(self, service_class):
